<?php
/*
Plugin Name: DEV Plugin-downloader (EasyToolsWP)
Plugin URI: https://www.easytoolswp.com/plugins/plugin-downloader-etwp.zip
Description: Tilføjer et download-link til hver plugin i administratorpanelet.
Version: 1.0
Author: EasyToolsWP.com
Author URI: https://www.easytoolswp.com
*/

// Aktivering og deaktivering af plugin
register_activation_hook(__FILE__, 'easytoolswp_plugin_downloader_activate');
register_deactivation_hook(__FILE__, 'easytoolswp_plugin_downloader_deactivate');

function easytoolswp_plugin_downloader_activate() {
    // Aktiveringshandling, hvis nødvendigt
}

function easytoolswp_plugin_downloader_deactivate() {
    // Deaktiveringshandling, hvis nødvendigt
}

// Tilføj download-link til hvert plugin
function easytoolswp_add_download_link($actions, $plugin_file, $plugin_data, $context) {
    // Hent stien til plugin-mappen
    $plugin_path = WP_PLUGIN_DIR . '/' . dirname($plugin_file);

    // Tilføj et link til at downloade hele mappen
    $actions['download_folder'] = '<a href="' . admin_url('admin-post.php?action=easytoolswp_download_plugin_folder&plugin=' . $plugin_file) . '">Download ▼</a>';
    return $actions;
}
add_filter('plugin_action_links', 'easytoolswp_add_download_link', 10, 4);

// Handling for download af plugin-mappen
add_action('admin_post_easytoolswp_download_plugin_folder', 'easytoolswp_download_plugin_folder_handler');

function easytoolswp_download_plugin_folder_handler() {
    // Sørg for at kun autoriserede brugere kan downloade
    if (!current_user_can('manage_options')) {
        wp_die('Unauthorized access.');
    }

    // Hent plugin-filnavn fra URL-parameter
    if (isset($_GET['plugin'])) {
        $plugin_file = sanitize_text_field($_GET['plugin']);

        // Find stien til plugin-mappen
        $plugin_path = WP_PLUGIN_DIR . '/' . dirname($plugin_file);

        // Sørg for at mappen eksisterer
        if (file_exists($plugin_path)) {
            // Opret en zip-fil
            $zip_filename = WP_CONTENT_DIR . '/plugins/' . basename($plugin_file) . '.zip';

            // Åbn en ny zip-arkivressource
            $zip = new ZipArchive();
            if ($zip->open($zip_filename, ZipArchive::CREATE | ZipArchive::OVERWRITE) === TRUE) {
                // Tilføj alle filer og mapper i plugin-mappen til zip-filen
                $files = new RecursiveIteratorIterator(
                    new RecursiveDirectoryIterator($plugin_path),
                    RecursiveIteratorIterator::LEAVES_ONLY
                );

                foreach ($files as $name => $file) {
                    if (!$file->isDir()) {
                        // Hent filstien
                        $file_path = $file->getRealPath();

                        // Opret den relative sti inde i zip-filen
                        $relative_path = substr($file_path, strlen(dirname($plugin_path)) + 1);

                        // Tilføj filen til zip-filen
                        $zip->addFile($file_path, $relative_path);
                    }
                }

                // Luk og gem zip-filen
                $zip->close();

                // Send zip-filen til browseren som en download
                header('Content-Type: application/zip');
                header('Content-Disposition: attachment; filename="' . basename($zip_filename) . '"');
                header('Content-Length: ' . filesize($zip_filename));
                readfile($zip_filename);

                // Slet den midlertidige zip-fil
                unlink($zip_filename);

                // Afslut scriptet
                exit;
            } else {
                // Hvis zip-åbningen mislykkes, vis fejlmeddelelse
                wp_die('Failed to create zip file.');
            }
        } else {
            // Hvis plugin-mappen ikke findes, vis fejlmeddelelse
            wp_die('Plugin folder not found.');
        }
    } else {
        // Hvis plugin parameter mangler, vis fejlmeddelelse
        wp_die('Plugin parameter missing.');
    }
}
